const os = require('os');
const rimraf = require('rimraf');
const { assert } = require('chai');

const { dirExists, listExists, getAndParseWords } = require('../src/fs-helpers');
const { newList } = require('../src/new');
const { addWord } = require('../src/add');
const { list } = require('../src/list');

const home = os.homedir();
const route = `${home}\\.my-own-words`;

const listName = 'italian';
const altListName = 'japanese';
const word = 'Ciao';
const wordDef = 'Hi';

describe('Before #list', () => {
  before(() => {
    rimraf.sync(route);
  });

  it('should delete the test directory', () => {
    assert.isFalse(dirExists());
  });

  it(`should create a clear test directory with an empty list called ${listName}`, () => {
    newList(listName);

    assert.isTrue(dirExists());
    assert.isTrue(listExists(listName));
    assert.isObject(getAndParseWords(listName));
  });
});

describe('#list', () => {
  it("should return an object with the available lists if don't receive a specific list", () => {
    assert.isArray(list());
    assert.include(list(), `${listName}.json`);
  });

  it('should return an object if a list is specified and it contains words', () => {
    addWord(listName, word, wordDef);

    assert.isObject(list(listName));
    assert.hasAnyKeys(list(listName), word);
  });

  it("should return an error message if the list specified doesn't exists", () => {
    assert.isString(list(altListName));
    assert.strictEqual(list(altListName), `${altListName} list doesn't exists!`);
  });
});
